Module result

Module result 

Structs

CaseResult
Result of a single test case for a single student.
FailureDetail
Detail about why a test case failed.
StudentReport
Complete report for a single student across all test specs.
TestResult
Aggregated result for one test spec (one TOML file) for one student.

Enums

TestStatus
Status of a single test case or an overall student report.