Structs
- Case
Result - Result of a single test case for a single student.
- Failure
Detail - Detail about why a test case failed.
- Student
Report - Complete report for a single student across all test specs.
- Test
Result - Aggregated result for one test spec (one TOML file) for one student.
Enums
- Test
Status - Status of a single test case or an overall student report.